# Table of Contents

- [sap-btp-reference-architecture-templates](<./sap-btp-reference-architecture-templates.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP BTP Reference Architecture Templates](<./SAP-BTP-Reference-Architecture-Templates.md>)
  - [Introduction](<./SAP-BTP-Reference-Architecture-Templates/Introduction.md>)
  - [Accessing and Using the Templates](<./SAP-BTP-Reference-Architecture-Templates/Accessing-and-Using-the-Templates.md>)
  - [Using SAP-Specific Shapes in Diagrams](<./SAP-BTP-Reference-Architecture-Templates/Using-SAP-Specific-Shapes-in-Diagrams.md>)
